###########################################################################
#AI2017:NIS data analysis                                                 #
#data used:Provided by contracting parties (member states) May/June 2016  #
#Data manipulated in excel                                                #
#analysis commenced 28.6.16                                               #
###########################################################################


rm(list=ls())
library(plyr)
library(graphics)
all<-read.csv(file.choose())#IA2017_data_Allcombined_final.csv
str(all)
all

#check data includes all years and countries# 
#############################################

unique(all$Year)
unique(all$Country)


#Duplication#
#############
#look for duplicated species within ospar region

#aggreagte by OSPAR region
str(all)
OSPARregion_species_year<-aggregate(all$Ospar.region, list(all$Ospar.region, all$Species, all$Year), count)
OSPARregion_species_year

OSPARregion_species_year_order<-OSPARregion_species_year[order(OSPARregion_species_year$Group.1),]#order by ospar region
OSPARregion_species_year_order

OSPARregion_species_year_order2<-OSPARregion_species_year[order(OSPARregion_species_year$Group.2),]#order by species
OSPARregion_species_year_order2

#count the number of records which refer to same region, species and year. 
countsOSPARregion_species<-count(all, c('Ospar.region', 'Species', 'Year') )
countsOSPARregion_species



#remove duplicates and perform anysis to determine the number of intros into OSPAR region#
##########################################################################################

#need to make sure that the data is ordered according to date first. Then it will removed duplicates leaving the earliest record
str(all)
sub<-all[,2:4]
sub
sub_dateorder<-sub[order(sub$Year),]
sub_dateorder
nrow(sub_dateorder)
#now remove duplicates 
noduplicates_OSPAR<-sub_dateorder[!duplicated(sub_dateorder[c(1,2)]),]
noduplicates_OSPAR

nrow(noduplicates_OSPAR)

noduplicates_OSPAR_check<-count(noduplicates_OSPAR, c('Ospar.region', 'Species', 'Year') )
noduplicates_OSPAR_check


#number introductions per region (no division by reporting period)
OSPAR_nodup_count<-count(noduplicates_OSPAR,'Ospar.region')
OSPAR_nodup_count

noduplicates_OSPAR_speciesorder<-noduplicates_OSPAR[order(noduplicates_OSPAR$Species),]
noduplicates_OSPAR_speciesorder


#introduced species per year by OSPAR region#
#############################################
OSPARregion_nodup_count_year<-count(noduplicates_OSPAR, c('Ospar.region', 'Year'))
OSPARregion_nodup_count_year

#need to add 0 freq data.
Ospar.region<-c("III","III","III", "IV")
Year<-c("2003","2013", "2014", "2014")
freq<-c(0,0,0, 0)

OSPARregionzero<-data.frame(Ospar.region, Year, freq)

#now repeat count
OSPARregion_nodup_count_year_inczero<-rbind(OSPARregion_nodup_count_year, OSPARregionzero)
OSPARregion_nodup_count_year2<-count(OSPARregion_nodup_count_year_inczero, c('Ospar.region', 'Year'))
OSPARregion_nodup_count_year2


#subset each region 
II<-subset(OSPARregion_nodup_count_year2, Ospar.region=="II")
II
III<-subset(OSPARregion_nodup_count_year2, Ospar.region=="III")
III
IV<-subset(OSPARregion_nodup_count_year2, Ospar.region=="IV")
IV



#total introductions per OSPAR region 

OSPARregion_nodup_count<-count(noduplicates_OSPAR,'Ospar.region') 
OSPARregion_nodup_count

bpt<-barplot(OSPARregion_nodup_count$freq, cex.name=1, las=1, names.arg=OSPARregion_nodup_count$OSPAR.region, ylim=c(0,250),
             ylab="Number of new NIS records 2003-2014", xlab="OSPAR region", main="", cex.lab=1.3, cex.axis=1.2)
text(x= bpt, y=OSPARregion_nodup_count$freq+2,label=OSPARregion_nodup_count$freq )

#export the data incase it is useful
#getwd()
#write.csv(noduplicates_OSPAR_check, "AI2017OSPARregion_specieslist_year.csv")


#introduced species per year by OSPAR region#
#############################################

OSPARregion_nodup_count_year<-count(noduplicates_OSPAR, c('Ospar.region', 'Year'))
OSPARregion_nodup_count_year

#export as excel table
#write.csv(OSPARregion_nodup_count_year, "AI2017_OSPARregion_nodup_count_year.csv")


#number of new introductions per Reporting period by OSPAR region. RP1=2003-2008, RP2=2009-2014#
################################################################################################
#reporting period 1

RP1_OSPAR<-subset(noduplicates_OSPAR, Year %in% c(2003, 2004, 2005, 2006, 2007, 2008))
RP1_OSPAR 
RP1OSPARregioncount<-count(RP1_OSPAR,'Ospar.region')
RP1OSPARregioncount

RP1yearcount<-count(RP1_OSPAR,'Year')
RP1yearcount

#reporting period 2
RP2_OSPAR<-subset(noduplicates_OSPAR, Year %in% c(2009, 2010, 2011, 2012, 2013, 2014))
RP2_OSPAR

RP2OSPARregioncount<-count(RP2_OSPAR,'Ospar.region')
RP2OSPARregioncount
RP2yearcount<-count(RP2_OSPAR, 'Year')
RP2yearcount

par()
# combine data for RP1 and RP2 using rbind
RP1_RP2_OSPARregioncount<-rbind(RP1OSPARregioncount, RP2OSPARregioncount)
RP1_RP2_OSPARregioncount
RP1_RP2_OSPARregioncount$RP<-c(1,1,1,2,2,2)
RP1_RP2_OSPARregioncount
RP1_RP2_OSPARregioncount_order<-RP1_RP2_OSPARregioncount[order(RP1_RP2_OSPARregioncount$Ospar.region),]
RP1_RP2_OSPARregioncount_order


#plot the introductions in RP1 and RP2 combined 
par(mfrow=c(1,1))
bpt1<-barplot(RP1_RP2_OSPARregioncount_order$freq, cex.name=1, las=1,  ylim=c(0,220),xlim=c(0,8),
              ylab="Number of new NIS introduced", xlab="OSPAR region", main="", cex.lab=1.3, cex.axis=1.2, col=c("grey89","grey30","grey89","grey30","grey89","grey30"))
axis(1, labels=c(" ","II","III","IV", " "),at=c(0, 1.3, 3.7, 6.1, 8), tck=0)
legend('topright', fill=c("grey89", "grey30"),  c("2003-2008", "2009-2014"))

text(x= bpt1, y=RP1_RP2_OSPARregioncount_order$freq+2,label=RP1_RP2_OSPARregioncount_order$freq)
mtext('The Number of new NIS introduced per reporting period into each Ospar region', outer=TRUE )


#T-test to determine whether significant different between introductions in period 1 and period 2#
##################################################################################################

#RP1
RP1_OSPAR
RP1_OSPAR_yearcount<-count(RP1_OSPAR,c('Ospar.region', 'Year'))
RP1_OSPAR_yearcount
#add zero data
Ospar.region<-c("III")
Year<-c("2003")
freq<-c(0)

OSPARregion_RP1_zero<-data.frame(Ospar.region, Year, freq)
OSPARregion_RP1_zero

RP1_OSPAR_yearcount_inczero<-rbind(RP1_OSPAR_yearcount, OSPARregion_RP1_zero)
RP1_OSPAR_yearcount_inczero

#subset by region
RP1_II<-subset(RP1_OSPAR_yearcount_inczero, Ospar.region=='II')
RP1_II
RP1_III<-subset(RP1_OSPAR_yearcount_inczero, Ospar.region=='III')
RP1_III
RP1_IV<-subset(RP1_OSPAR_yearcount_inczero, Ospar.region=='IV')
RP1_IV

#RP1
RP2_OSPAR
RP2_OSPAR_yearcount<-count(RP2_OSPAR,c('Ospar.region', 'Year'))
RP2_OSPAR_yearcount

Ospar.region<-c("III", "III", "IV" )
Year<-c("2013", "2014", "2014")
freq<-c(0, 0, 0)

OSPARregion_RP2_zero<-data.frame(Ospar.region, Year, freq)
OSPARregion_RP2_zero

RP2_OSPAR_yearcount_inczero<-rbind(RP2_OSPAR_yearcount, OSPARregion_RP2_zero)
RP2_OSPAR_yearcount_inczero


RP2_II<-subset(RP2_OSPAR_yearcount_inczero, Ospar.region=='II')
RP2_II
RP2_III<-subset(RP2_OSPAR_yearcount_inczero, Ospar.region=='III')
RP2_III
RP2_IV<-subset(RP2_OSPAR_yearcount_inczero, Ospar.region=='IV')
RP2_IV


#t test#
########
#all regions
RP2yearcount
RP2yearcount

t.test(RP1yearcount$freq, RP2yearcount$freq)


#region II
RP1_II
RP2_II

t.test(RP1_II$freq, RP2_II$freq)

#region III
RP1_III
RP2_III

t.test(RP1_III$freq, RP2_III$freq)

#regon IV
RP1_IV
RP2_IV

t.test(RP1_IV$freq, RP2_IV$freq)

#boxplot#
#########
#all regions
par(mfrow=c(1,1))
par(mar=c(5,5,4,2))
par(oma=c(1,1,2,1))
boxplot(RP1yearcount$freq, RP2yearcount$freq, ylab='Number of new NIS records', xlab='Reporting period', main='All Ospar regions') 
axis(1, labels=c(" 1","2"),at=c(1,2), tck=0)

par(mar=c(4,5,2,1))
par(oma=c(2,0,2,0))
par(mfrow=c(3,1))

#region II

boxplot(RP1_II$freq, RP2_II$freq, ylab='Number of new NIS records', xlab='Reporting period', main='Ospar region II', ylim=c(0,14)) 
axis(1, labels=c(" 1","2"),at=c(1,2), tck=0)


#region III
boxplot(RP1_III$freq, RP2_III$freq, ylab='Number of new NIS records', xlab='Reporting period', main='Ospar region III')
axis(1, labels=c(" 1","2"),at=c(1,2), tck=0)

#region IV
boxplot(RP1_IV$freq, RP2_IV$freq, ylab='Number of new NIS records', xlab='Reporting period', main='Ospar region IV')
axis(1, labels=c(" 1","2"),at=c(1,2), tck=0)

mtext('The Number of new NIS records per reporting period into each Ospar region', outer=TRUE, cex=0.8 )


#plot -number of new introductions per year by OSPAR region#
############################################################
par(mfrow=c(1,1))
par(mar=c(5,5,4,2))
par(oma=c(1,1,2,1))

#whole region
nodup_count_year<-count(noduplicates_OSPAR, c( 'Year'))
nodup_count_year


barplot(nodup_count_year$freq, pch=1, lwd=1.8, xlab="Year", ylim=c(0,140), xlim=c(0,15), ylab="Number of new NIS records", main="All Ospar regions")
axis(1, labels=c('2003','2004','2005','2006','2007','2008','2009','2010','2011','2012', '2013', '2014'),at=c(0.7,1.90, 3.15, 4.35,5.6,6.8, 7.9,9.15,10.3,11.5,12.7,13.9), tck=0)


#plots
par(mfrow=c(3,1))
#region II
barplot(II$freq, pch=1, lwd=1.8, xlab="Year", ylim=c(0,20), xlim=c(0,15), ylab="Number of new NIS introduced", main="Ospar region II")
axis(1, labels=c('2003','2004','2005','2006','2007','2008','2009','2010','2011','2012', '2013', '2014'),at=c(0.7,1.90, 3.15, 4.35,5.6,6.8, 7.9,9.15,10.3,11.5,12.7,13.9), tck=0)


#region III
barplot(III$freq, pch=1, lwd=1.8, xlab="Year", ylim=c(0,15), xlim=c(0,14),ylab="Number of new NIS introduced", main="Ospar region III") 
axis(1, labels=c('2003','2004','2005','2006','2007','2008','2009','2010','2011','2012', '2013', '2014'),at=c(0.7,1.90, 3.15, 4.35,5.6,6.8, 7.9,9.15,10.3,11.5,12.7,13.9), tck=0)


#region IV
barplot(IV$freq, pch=1, lwd=1.8, xlab="Year", ylim=c(0,120), xlim=c(0,14),ylab="Number of new NIS introduced", main="Ospar region IV")
axis(1, labels=c('2003','2004','2005','2006','2007','2008','2009','2010','2011','2012', '2013', '2014'),at=c(0.7,1.90, 3.15, 4.35,5.6,6.8, 7.9,9.15,10.3,11.5,12.7,13.9), tck=0)

mtext('The Number of new NIS records per year into each Ospar region', outer=TRUE, cex=0.8 )


#cumulative number of introductions#
####################################
#all regions
nodup_count_year
cumfreqall<-cumsum(nodup_count_year$freq)
cumfreqall
nodup_count_year$cumfreq<-cumfreqall
nodup_count_year$cumfreq

#region II
cumfreqII<-cumsum(II$freq)
II$cumfreq<-cumfreqII
II

#region III
cumfreqIII<-cumsum(III$freq)
III$cumfreq<-cumfreqIII
III

#region IV
cumfreqIV<-cumsum(IV$freq)
IV$cumfreq<-cumfreqIV
IV


#plots
par(mfrow=c(3,1))
par(mar=c(5,5,4,2))
par(oma=c(1,1,2,1))

#region II
barplot(II$cumfreq, pch=1, lwd=1.8, xlab="Year",ylim=c(0,120), ylab="Cumulative number of new NIS introduced ", main="Ospar region II")
axis(1, labels=c('2003','2004','2005','2006','2007','2008','2009','2010','2011','2012', '2013', '2014'),at=c(0.7,1.90, 3.15, 4.35,5.6,6.8, 7.9,9.15,10.3,11.5,12.7,13.9), tck=0)
#region III
barplot(III$cumfreq, pch=1, lwd=1.8, xlab="Year", ylim=c(0, 40), ylab="Cumulative number of new NIS introduced", main="Ospar region III") 
axis(1, labels=c('2003','2004','2005','2006','2007','2008','2009','2010','2011','2012', '2013', '2014'),at=c(0.7,1.90, 3.15, 4.35,5.6,6.8, 7.9,9.15,10.3,11.5,12.7,13.9), tck=0)
#region IV
barplot(IV$cumfreq, pch=1, lwd=1.8, xlab="Year", ylim=c(0,250), ylab="Cumulative number of new NIS introduced", main="Ospar region IV")
axis(1, labels=c('2003','2004','2005','2006','2007','2008','2009','2010','2011','2012', '2013', '2014'),at=c(0.7,1.90, 3.15, 4.35,5.6,6.8, 7.9,9.15,10.3,11.5,12.7,13.9), tck=0)

mtext('The Cumulative number of new NIS introduced per year into each Ospar region', outer=TRUE )

##############################
#introductions and cumulative introductions combined
par(mar=c(4,5,2,1))
par(oma=c(0,0,2,0))
par(mfrow=c(3,1))


#all
allcombplot<-barplot(nodup_count_year$freq, pch=1, lwd=1.8, xlab="Year", ylim=c(0,380), xlim=c(0,15), ylab="Number of new NIS records")
axis(1, labels=c('2003','2004','2005','2006','2007','2008','2009','2010','2011','2012', '2013', '2014'),at=c(0.7,1.90, 3.15, 4.35,5.6,6.8, 7.9,9.15,10.3,11.5,12.7,13.9), tck=0)
lines(allcombplot, nodup_count_year$cumfreq)
points(allcombplot, nodup_count_year$cumfreq)
mtext('The number of new NIS records per year into the all Ospar regions', outer=TRUE)
(legend('topleft', lty=1, pch=1,  c("cumulative number"), cex=0.8))



#regionII
IIcombplot <- barplot(II$freq, ylim=c(0,120), ylab='Number of new NIS records', xlab='Year', main='Region II')               
lines(IIcombplot, II$cumfreq)
points(IIcombplot,II$cumfreq)
axis(1, labels=c('2003','2004','2005','2006','2007','2008','2009','2010','2011','2012', '2013', '2014'),at=c(0.7,1.90, 3.15, 4.35, 5.6, 6.8, 7.9, 9.15, 10.3,11.5,12.7,13.9), tck=0, cex.lab=0.1)
mtext('The number of new NIS records per year in each Ospar region', outer=TRUE)
(legend('topleft', lty=1, pch=1,  c("cumulative number"), cex=0.8))
#regionIII
IIIcombplot <- barplot(III$freq, ylim=c(0,40), ylab='Number of new NIS records', xlab='Year', main='Region III')
lines(IIIcombplot, III$cumfreq)
points(IIIcombplot,III$cumfreq)
axis(1, labels=c('2003','2004','2005','2006','2007','2008','2009','2010','2011','2012', '2013', '2014'),at=c(0.7,1.90, 3.15, 4.35, 5.6, 6.8, 7.9, 9.15, 10.3,11.5,12.7,13.9), tck=0, cex=0.8)
#region IV
IVcombplot <- barplot(IV$freq, ylim=c(0,250), ylab='Number of new NIS recorss', xlab='Year', main='Region IV')
lines(IVcombplot, IV$cumfreq)
points(IVcombplot,IV$cumfreq)
axis(1, labels=c('2003','2004','2005','2006','2007','2008','2009','2010','2011','2012', '2013', '2014'),at=c(0.7,1.90, 3.15, 4.35, 5.6, 6.8, 7.9, 9.15, 10.3,11.5,12.7,13.9), tck=0, cex=0.8)

